@@ -30,7 +30,7 @@
 #include <Lum/Panel.h>
 #include <Lum/Toggle.h>
 
-#include <Lum/OS/Manager/Repository.h>
+#include <Lum/Manager/Display.h>
 
 #include "Configuration.h"
 
@@ -102,7 +102,7 @@ void Countdown::PlayAlert()
 
 void Countdown::AllowScreenBlanking(bool allow)
 {
-  Lum::OS::Manager::DisplayManager *displayManager=Lum::OS::Manager::repository->GetDisplayManager();
+  Lum::Manager::Display *displayManager=Lum::Manager::Display::Instance();
 
   if (displayManager!=NULL) {
     displayManager->AllowScreenBlanking(allow);
@@ -236,7 +236,7 @@ void Countdown::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
       clock->GetClickAction()->IsFinished() &&
       state==stateStoped) {
     Lum::Dlg::TimeSpanChooser *chooser;
-    Lum::Model::SizeTRef      seconds=new Lum::Model::SizeT(initialSeconds);
+    Lum::Model::ULongRef      seconds=new Lum::Model::ULong(initialSeconds);
 
     chooser=new Lum::Dlg::TimeSpanChooser(seconds);
     chooser->SetParent(GetWindow());
