@@ -26,7 +26,7 @@
 
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Boolean.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 #include "StopWatch.h"
 
@@ -47,7 +47,7 @@ private:
   Lum::Model::ActionRef  stopAction;
   Lum::Model::ActionRef  timer;
 
-  size_t                 initialSeconds;
+  unsigned long          initialSeconds;
   Lum::Base::Timer       time;
 
   State                  state;
