@@ -26,7 +26,7 @@
 
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Boolean.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 #include <Lum/Model/Table.h>
 
 #include <Lum/Table.h>
